.. Pyskema documentation master file, created by
   sphinx-quickstart on Tue Mar  7 14:56:46 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pyskema's documentation!
===================================

Pyskema is a small module used to define schema for structured data.

The schema can be used to validate, document and generate data.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ref/pyskema

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
